﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Configuration;

public partial class Checkout : System.Web.UI.Page
{

    #region Configuration Parameters
    
    string MerchantId
    {
        get { return ConfigurationManager.AppSettings["merchantId"]; }
    }

    string Token
    {
        get { return ConfigurationManager.AppSettings["token"]; }
    }

    string RedirectUrl
    {
        get { return ConfigurationManager.AppSettings["redirectUrl"]; }
    }

    string TerminalUrl
    {
        get { return ConfigurationManager.AppSettings["terminalUrl"]; }
    }

    #endregion

    /// <summary>
    /// Set the postback URL of the pay button after the necessary values are available
    /// </summary>
    string ButtonUrl
    {
        set
        {
            btnPay.PostBackUrl = value;
        }
    }


    /// <summary>
    /// 
    /// </summary>
    protected void Page_Load(object sender, EventArgs e)
    {
        try
        {
            BBS.Netaxept client = new BBS.Netaxept();

            // Setup the terminal parameters (required parameters for Netaxept-hosted terminal)
            BBS.Terminal terminal = new BBS.Terminal();
            terminal.OrderDescription = "Just a test transaction";
            terminal.RedirectUrl = RedirectUrl;

            // Setup the order (required parameters)
            BBS.Order order = new BBS.Order();
            order.Amount = "39500";          // 395,00
            order.CurrencyCode = "NOK";      // Norwegian Kroner
            order.OrderNumber = "12345";     // A number to be able to track the order

            // Setup the environment (required for all web service clients)
            BBS.Environment environment = new BBS.Environment();
            environment.WebServicePlatform = "DOTNET20";

            // Finally the complete register request
            BBS.RegisterRequest request = new BBS.RegisterRequest();
            request.Order = order;
            request.Terminal = terminal;
            request.Environment = environment;

            BBS.RegisterResponse response = client.Register(MerchantId, Token, request);

            // Set the postback URL of the pay button to the terminal
            lblTransactionId.Text = response.TransactionId;
            ButtonUrl = String.Format(TerminalUrl, MerchantId, response.TransactionId);
            btnPay.Enabled = true;
        }
        catch (Exception ex)
        {
            lblError.Text = ex.ToString();
            btnPay.Enabled = false;
        }
    }
}