﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Configuration;

public partial class LandingPage : System.Web.UI.Page
{
    #region Configuration Parameters

    string MerchantId
    {
        get { return ConfigurationManager.AppSettings["merchantId"]; }
    }

    string Token
    {
        get { return ConfigurationManager.AppSettings["token"]; }
    }

    #endregion

    #region URL parameters



    string ResponseCode
    {
        get { return Request.QueryString["responseCode"]; }
    }

    string TransactionId
    {
        get
        {
            if (String.IsNullOrEmpty(Request.QueryString["transactionId"]) == false)
            {
                ViewState["transactionId"] = Request.QueryString["transactionId"];
            }
            return (string)ViewState["transactionId"];
        }
    }

    #endregion

    bool showFinancialTransactions = true;
    bool ShowFinancialTransactions
    {
        get { return showFinancialTransactions; }
        set { showFinancialTransactions = value; }
    }

    #region UI communication

    new string Error
    {
        set { lblError.Text = value; }
    }

    string Status
    {
        set { lblStatus.Text = value; }
    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        if (IsPostBack == false)
        {
            lblTransactionId.Text = TransactionId;
            if (ResponseCode == "Cancel")
            {
                LandingHeader.InnerText = "The purchase was canceled!";
                ShowFinancialTransactions = false;
            }
            // This block is actually not required for normal terminal usage, as the customer
            // will only return with responseCode == "OK" or responseCode == "Cancel".

                // If the setting "RedirectOnError" is set to true, the customer will be returned
            // from the terminal whenever something fails (such as a declined card), and
            // this block can be enabled to see what failed.
#if false
            else if (ResponseCode != "OK")
            {
                LandingHeader.InnerText = "The purchase failed!";

                BBS.Netaxept client = new BBS.Netaxept();
                BBS.QueryRequest request = new BBS.QueryRequest();
                request.TransactionId = TransactionId;
                BBS.QueryResponse response = client.Query(MerchantId, Token, request);
                BBS.PaymentInfo paymentInfo = (BBS.PaymentInfo)response;
                Error = String.Format("{0}/{1}: {2}", paymentInfo.Error.ResponseCode, paymentInfo.Error.ResponseSource, paymentInfo.Error.ResponseText);
            }
#endif
            else
            {
                ShowFinancialTransactions = true;
            }
        }

        if (ShowFinancialTransactions)
        {
            divFinancialTransactions.Visible = true;
        }
        else
        {
            divFinancialTransactions.Visible = false;
        }
    }

    // Run an authorization
    protected void btnAuth_Click(object sender, EventArgs e)
    {
        try
        {
            ShowFinancialTransactions = true;
            BBS.Netaxept client = new BBS.Netaxept();
            BBS.ProcessRequest request = new BBS.ProcessRequest();
            request.Operation = "AUTH";
            request.TransactionId = TransactionId;

            client.Process(MerchantId, Token, request);
            Status = "Transaction AUTH'ed OK.";
            Error = String.Empty;
        }
        catch (Exception ex)
        {
            Status = String.Empty;
            Error = ex.ToString();
        }
    }

    protected void btnSale_Click(object sender, EventArgs e)
    {
        try
        {
            ShowFinancialTransactions = true;
            BBS.Netaxept client = new BBS.Netaxept();
            BBS.ProcessRequest request = new BBS.ProcessRequest();
            request.Operation = "SALE";
            request.TransactionId = TransactionId;

            client.Process(MerchantId, Token, request);
            Status = "Transaction SALE'ed OK.";
            Error = String.Empty;
        }
        catch (Exception ex)
        {
            Status = String.Empty;
            Error = ex.ToString();
        }
    }

    protected void btnAnnul_Click(object sender, EventArgs e)
    {
        try
        {
            ShowFinancialTransactions = true;
            BBS.Netaxept client = new BBS.Netaxept();
            BBS.ProcessRequest request = new BBS.ProcessRequest();
            request.Operation = "ANNUL";
            request.TransactionId = TransactionId;

            client.Process(MerchantId, Token, request);
            Status = "Transaction ANNULed OK.";
            Error = String.Empty;

        }
        catch (Exception ex)
        {
            Status = String.Empty;
            Error = ex.ToString();
        }
    }

    protected void btnCapture_Click(object sender, EventArgs e)
    {
        try
        {
            ShowFinancialTransactions = true;
            BBS.Netaxept client = new BBS.Netaxept();
            BBS.ProcessRequest request = new BBS.ProcessRequest();
            request.Operation = "CAPTURE";
            request.TransactionId = TransactionId;
            if (string.IsNullOrEmpty(tbxCaptureAmount.Text) == false)
            {
                request.TransactionAmount = tbxCaptureAmount.Text;
            }

            client.Process(MerchantId, Token, request);
            Status = "Transaction CAPTUREd OK.";
            Error = String.Empty;

        }
        catch (Exception ex)
        {
            Status = String.Empty;
            Error = ex.ToString();
        }
    }

    protected void btnCredit_Click(object sender, EventArgs e)
    {
        try
        {
            ShowFinancialTransactions = true;
            BBS.Netaxept client = new BBS.Netaxept();
            BBS.ProcessRequest request = new BBS.ProcessRequest();
            request.Operation = "CREDIT";
            request.TransactionId = TransactionId;
            if (string.IsNullOrEmpty(tbxCreditAmount.Text) == false)
            {
                request.TransactionAmount = tbxCreditAmount.Text;
            }

            client.Process(MerchantId, Token, request);
            Status = "Transaction CREDITed OK.";
            Error = String.Empty;
        }
        catch (Exception ex)
        {
            Status = String.Empty;
            Error = ex.ToString();
        }
    }

    string ToXml(object output)
    {
        string objectAsXmlString;

        System.Xml.Serialization.XmlSerializer xs = new System.Xml.Serialization.XmlSerializer(output.GetType());
        using (System.IO.StringWriter sw = new System.IO.StringWriter())
        {
            try
            {
                xs.Serialize(sw, output);
                objectAsXmlString = sw.ToString();
            }
            catch (Exception ex)
            {
                objectAsXmlString = "Serializing object for logging failed: " + ex.ToString();
            }
        }

        return objectAsXmlString;
    }

    protected void btnQuery_Click(object sender, EventArgs e)
    {
        BBS.Netaxept client = new BBS.Netaxept();
        BBS.QueryRequest request = new BBS.QueryRequest();
        request.TransactionId = TransactionId;
        BBS.QueryResponse response = client.Query(MerchantId, Token, request);

        // The response needs to be casted to an instance of payment info
        BBS.PaymentInfo paymentInfo = (BBS.PaymentInfo)response;
        string output = ToXml(paymentInfo);
        output = output.Replace("<", "&lt;").Replace(">", "&gt;").Replace(" ", "&nbsp;").Replace("\n", "<br/>");
        Status = output;
        Error = String.Empty;
    }
}